"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = selectAdhocProvisioningProfile;

var _ora = _interopRequireDefault(require("ora"));

var _fastlane = require("../build/ios/appleApi/fastlane");

var _tagger = require("./tagger");

var _log = _interopRequireDefault(require("../../log"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

async function selectAdhocProvisioningProfile(context, udids, distCertSerialNumber, options = {}) {
  const spinner = (0, _ora.default)(`Handling Adhoc provisioning profiles on Apple Developer Portal...`).start();
  const args = ['--apple-id', context.appleId, '--apple-password', context.appleIdPassword, context.team.id, udids, context.bundleIdentifier, distCertSerialNumber];
  const adhocProvisioningProfile = await (0, _fastlane.runAction)(_fastlane.travelingFastlane.manageAdHocProvisioningProfile, args);
  const {
    provisioningProfileUpdateTimestamp,
    provisioningProfileCreateTimestamp,
    provisioningProfileName
  } = adhocProvisioningProfile;

  if (provisioningProfileCreateTimestamp) {
    spinner.succeed(`Created new profile: ${provisioningProfileName}`);
  } else if (provisioningProfileUpdateTimestamp) {
    spinner.succeed(`Updated existing profile: ${provisioningProfileName}`);
  } else {
    spinner.succeed(`Used existing profile: ${provisioningProfileName}`);
  } // tag for updating to Expo servers


  (0, _tagger.tagForUpdate)(adhocProvisioningProfile);
  return adhocProvisioningProfile;
}
//# sourceMappingURL=../../__sourcemaps__/commands/client/selectAdhocProvisioningProfile.js.map
