"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.displayAndroidCredentials = displayAndroidCredentials;
exports.displayAndroidAppCredentials = displayAndroidAppCredentials;

var _chalk = _interopRequireDefault(require("chalk"));

var _isEmpty = _interopRequireDefault(require("lodash/isEmpty"));

var _fsExtra = _interopRequireDefault(require("fs-extra"));

var _get = _interopRequireDefault(require("lodash/get"));

var _xdl = require("@expo/xdl");

var _log = _interopRequireDefault(require("../../log"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

async function displayAndroidCredentials(credentialsList) {
  (0, _log.default)(_chalk.default.bold('Available Android credentials'));
  (0, _log.default)();

  for (const credentials of credentialsList) {
    await displayAndroidAppCredentials(credentials);
  }
}

async function displayAndroidAppCredentials(credentials) {
  const tmpFilename = `expo_tmp_keystore_file.jks`;

  try {
    if (await _fsExtra.default.pathExists(tmpFilename)) {
      await _fsExtra.default.unlink(tmpFilename);
    }

    (0, _log.default)(_chalk.default.green(credentials.experienceName));
    (0, _log.default)(_chalk.default.bold('  Upload Keystore hashes'));

    if (!(0, _isEmpty.default)(credentials.keystore)) {
      const storeBuf = Buffer.from((0, _get.default)(credentials, 'keystore.keystore'), 'base64');
      await _fsExtra.default.writeFile(tmpFilename, storeBuf);
      await _xdl.AndroidCredentials.logKeystoreHashes({
        keystorePath: tmpFilename,
        ...credentials.keystore
      }, '    ');
    } else {
      (0, _log.default)('    -----------------------');
    }

    (0, _log.default)(_chalk.default.bold('  Push Notifications credentials'));
    (0, _log.default)('    FCM Api Key: ', (0, _get.default)(credentials, 'pushCredentials.fcmApiKey', '---------------------'));
    (0, _log.default)('\n');
  } catch (error) {
    _log.default.error('  Failed to parse the keystore', error);

    (0, _log.default)('\n');
  } finally {
    if (await _fsExtra.default.pathExists(tmpFilename)) {
      await _fsExtra.default.unlink(tmpFilename);
    }
  }
}
//# sourceMappingURL=../../__sourcemaps__/credentials/actions/list.js.map
