"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.askQuit = askQuit;
exports.SelectAndroidExperience = exports.SelectPlatform = void 0;

var _get = _interopRequireDefault(require("lodash/get"));

var _prompt = _interopRequireDefault(require("../../prompt"));

var _log = _interopRequireDefault(require("../../log"));

var androidCredentials = _interopRequireWildcard(require("./AndroidCredentials"));

var _route = require("../route");

var _list = require("../actions/list");

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {}; if (desc.get || desc.set) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj.default = obj; return newObj; } }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

class SelectPlatform {
  async open(context) {
    const {
      platform
    } = await (0, _prompt.default)([{
      type: 'list',
      name: 'platform',
      message: 'Select platform',
      pageSize: Infinity,
      choices: ['ios', 'android']
    }]);
    const view = platform === 'ios' ? new SelectPlatform() : new SelectAndroidExperience();
    (0, _route.changeMainView)(view);
    return view;
  }

}

exports.SelectPlatform = SelectPlatform;

class SelectAndroidExperience {
  constructor() {
    _defineProperty(this, "androidCredentials", []);

    _defineProperty(this, "askAboutProjectMode", true);
  }

  async open(ctx) {
    if (ctx.hasProjectContext && this.askAboutProjectMode) {
      const experienceName = `@${ctx.user.username}/${ctx.manifest.slug}`;
      const {
        runProjectContext
      } = await (0, _prompt.default)([{
        type: 'confirm',
        name: 'runProjectContext',
        message: `You are currently in a directory with ${experienceName} experience. Do you want to select it?`
      }]);

      if (runProjectContext) {
        const view = new androidCredentials.ExperienceView(ctx.manifest.slug, null);
        (0, _route.changeMainView)(view);
        return view;
      }
    }

    this.askAboutProjectMode = false;

    if (this.androidCredentials) {
      this.androidCredentials = (0, _get.default)((await ctx.api.getAsync('credentials/android')), 'credentials');
    }

    await (0, _list.displayAndroidCredentials)(this.androidCredentials);
    const question = {
      type: 'list',
      name: 'appIndex',
      message: 'Select application',
      choices: this.androidCredentials.map((cred, index) => ({
        name: cred.experienceName,
        value: index
      })),
      pageSize: Infinity
    };
    const {
      appIndex
    } = await (0, _prompt.default)(question);
    const matchName = this.androidCredentials[appIndex].experienceName.match(/@[\w.-]+\/([\w.-]+)/);

    if (matchName && matchName[1]) {
      return new androidCredentials.ExperienceView(matchName[1], this.androidCredentials[appIndex]);
    } else {
      _log.default.error('Invalid experience name');
    }

    return null;
  }

}

exports.SelectAndroidExperience = SelectAndroidExperience;

async function askQuit(mainpage) {
  const {
    selected
  } = await (0, _prompt.default)([{
    type: 'list',
    name: 'selected',
    message: 'Do you want to quit Credential Manager',
    choices: [{
      value: 'exit',
      name: 'Quit Credential Manager'
    }, {
      value: 'mainpage',
      name: 'Go back to experience overview.'
    }]
  }]);

  if (selected === 'exit') {
    process.exit(0);
  }

  return mainpage;
}
//# sourceMappingURL=../../__sourcemaps__/credentials/views/Select.js.map
